<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\Icon;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the icon id.
 *
 * @property-read float $value The raw value.
 */
final class Scale {
	/**
	 * The scale value of the icon.
	 *
	 * @var float
	 */
	private readonly float $value;

	/**
	 * The constructor.
	 *
	 * @param mixed $value The id of the icon.
	 * @throws \InvalidArgumentException If the id is not numeric or less than 1.
	 */
	public function __construct( mixed $value ) {
		if ( ! is_int( $value ) && ! is_float( $value ) && ! is_string( $value ) ) {
			throw new \InvalidArgumentException( 'The value must be an int|float or a string.' );
		}
		if ( ! is_numeric( $value ) ) {
			throw new \InvalidArgumentException( 'The value must be numeric.' );
		}

		$value = floatval( $value );
		if ( $value <= 0.0 ) {
			throw new \InvalidArgumentException( 'The value must be greater than 0.0.' );
		}
		if ( $value > 10.0 ) {
			throw new \InvalidArgumentException( 'The value must be less than or equal to 10.0.' );
		}

		$this->value = $value;
	}

	/**
	 * The magick getter.
	 *
	 * @param string $name The name of the property.
	 * @throws \InvalidArgumentException If the property does not exist.
	 */
	public function __get( string $name ): mixed {
		return match ( $name ) {
			'value' => $this->value,
			default => throw new \InvalidArgumentException( 'The property "' . esc_html( $name ) . '" does not exist.' ),
		};
	}
}
